/*
 * System Interface Library for games
 * Copyright (c) 2007-2014 Andrew Church <achurch@achurch.org>
 * Released under the GNU GPL version 3 or later; NO WARRANTY is provided.
 * See the file COPYING.txt for details.
 *
 * src/sysdep/macosx/filedata.h: Header for the SILFileData URL protocol class.
 */

/*
 * The SILFileDataURLProtocol class implements a URL protocol "silfiledata://"
 * which allows access to a selected byte range of a file.  This is required
 * to play back movies embedded in a package file, since none of the system
 * interfaces allow specifying a specific range within a file as the data
 * source.
 *
 * Syntax: silfiledata:///<SysFile>/<start>/<length>
 *     <SysFile>: File handle (SysFile pointer) to read from, as a hexadecimal
 *         string (strformat("%p",...) will suffice); the caller is responsible
 *         for keeping the handle valid as long as the URL is in use.
 *     <start>: Byte offset within the file of the data to access.
 *     <length>: Length (in bytes) of the data to access.
 *
 * The actual implementation is in filedata.m; this file only contains the
 * declaration of osx_filedata_register(), used to register the protocol
 * with the system.
 */

#ifndef SIL_SRC_SYSDEP_MACOSX_FILEDATA_H
#define SIL_SRC_SYSDEP_MACOSX_FILEDATA_H

/*************************************************************************/
/*************************************************************************/

/**
 * osx_filedata_register:  Register the silfiledata:// protocol with the
 * system.
 *
 * [Return value]
 *     True on success, false on error.
 */
extern int osx_filedata_register(void);

/*************************************************************************/
/*************************************************************************/

#endif  // SIL_SRC_SYSDEP_MACOSX_FILEDATA_H

/*
 * Local variables:
 *   c-file-style: "stroustrup"
 *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
 *   indent-tabs-mode: nil
 * End:
 *
 * vim: expandtab shiftwidth=4:
 */
